# bug

If you find a bug in pytoil, want to submit a feature request, or just have a question to ask, you can easily open up pytoil's issues page with `pytoil bug`.

<div class="termy">

```console
$ pytoil bug

Opening pytoil's issues in your browser...

// Now you're at our issues page!
```

</div>
